==> apache-servicecomb-java-chassis-distribution-2.1.1-src.zip: apache-servicecomb-java-chassis-distribution-2.1.1-src/foundations/foundation-vertx/src/main/java/org/apache/servicecomb/foundation/vertx/http/EmptyAsyncContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.foundation.vertx.http;

import javax.servlet.AsyncContext;
import javax.servlet.AsyncListener;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;

public class EmptyAsyncContext implements AsyncContext {
  @Override
  public ServletRequest getRequest() {
    return null;
  }

  @Override
  public ServletResponse getResponse() {
    return null;
  }

  @Override
  public boolean hasOriginalRequestAndResponse() {
    return false;
  }

  @Override
  public void dispatch() {

  }

  @Override
  public void dispatch(String path) {

  }

  @Override
  public void dispatch(ServletContext context, String path) {

  }

  @Override
  public void complete() {

  }

  @Override
  public void start(Runnable run) {

  }

  @Override
  public void addListener(AsyncListener listener) {

  }

  @Override
  public void addListener(AsyncListener listener, ServletRequest servletRequest, ServletResponse servletResponse) {

  }

  @Override
  public <T extends AsyncListener> T createListener(Class<T> clazz) throws ServletException {
    return null;
  }

  @Override
  public void setTimeout(long timeout) {

  }

  @Override
  public long getTimeout() {
    return 0;
  }
}

==> apache-servicecomb-java-chassis-distribution-2.9.3-src.zip: apache-servicecomb-java-chassis-distribution-2.9.3-src/foundations/foundation-vertx/src/main/java/org/apache/servicecomb/foundation/vertx/http/EmptyAsyncContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.foundation.vertx.http;

import jakarta.servlet.AsyncContext;
import jakarta.servlet.AsyncListener;
import jakarta.servlet.ServletContext;
import jakarta.servlet.ServletException;
import jakarta.servlet.ServletRequest;
import jakarta.servlet.ServletResponse;

public class EmptyAsyncContext implements AsyncContext {
  @Override
  public ServletRequest getRequest() {
    return null;
  }

  @Override
  public ServletResponse getResponse() {
    return null;
  }

  @Override
  public boolean hasOriginalRequestAndResponse() {
    return false;
  }

  @Override
  public void dispatch() {

  }

  @Override
  public void dispatch(String path) {

  }

  @Override
  public void dispatch(ServletContext context, String path) {

  }

  @Override
  public void complete() {

  }

  @Override
  public void start(Runnable run) {

  }

  @Override
  public void addListener(AsyncListener listener) {

  }

  @Override
  public void addListener(AsyncListener listener, ServletRequest servletRequest, ServletResponse servletResponse) {

  }

  @Override
  public <T extends AsyncListener> T createListener(Class<T> clazz) throws ServletException {
    return null;
  }

  @Override
  public void setTimeout(long timeout) {

  }

  @Override
  public long getTimeout() {
    return 0;
  }
}
